package
module
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Mar 6, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
func AddRoute[TSource, TDest any | []any](mapFunc func(source TSource, dest *TDest) error) error
func Map(source interface{}, dest interface{}) error
Map source to dest
func MapTo[TDest interface{}](source interface{}) (TDest, error)
MapTo Map source to the new dest object
Source Files
¶
Click to show internal directories.
Click to hide internal directories.