package
module
Version:
v0.0.2
Opens a new window with list of versions in this module.
Published: Sep 7, 2023
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
const RouteNotFoundError = "route does not exist in route map"
func AddRoute[TSource, TDest any | []any](mapFunc func(source TSource, dest *TDest) error) error
func Map(source interface{}, dest interface{}) error
Map source to dest
func MapTo[TDest interface{}](source interface{}) (TDest, error)
MapTo Map source to the new dest object
Source Files
¶
Click to show internal directories.
Click to hide internal directories.